You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ts...@apache.org on 2022/10/18 04:16:50 UTC

[camel-k] 02/03: fix(cmd): fix typos in kamelet_add_repo.go

This is an automated email from the ASF dual-hosted git repository.

tsato pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-k.git

commit b6be2503e4a5cdd8fe66f201a22f81d0db46aa91
Author: Tadayoshi Sato <sa...@gmail.com>
AuthorDate: Mon Oct 17 18:51:17 2022 +0900

    fix(cmd): fix typos in kamelet_add_repo.go
---
 pkg/cmd/kamelet_add_repo.go    | 12 ++++++------
 pkg/cmd/kamelet_remove_repo.go |  4 ++--
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/pkg/cmd/kamelet_remove_repo.go b/pkg/cmd/kamelet_remove_repo.go
index 18703681f..1e7614881 100644
--- a/pkg/cmd/kamelet_remove_repo.go
+++ b/pkg/cmd/kamelet_remove_repo.go
@@ -68,9 +68,9 @@ func (o *kameletRemoveRepoCommandOptions) run(cmd *cobra.Command, args []string)
 	}
 	var platform *v1.IntegrationPlatform
 	if o.OperatorID == "" {
-		platform, err = o.findIntegrationPlatorm(cmd, c)
+		platform, err = o.findIntegrationPlatform(cmd, c)
 	} else {
-		platform, err = o.getIntegrationPlatorm(cmd, c)
+		platform, err = o.getIntegrationPlatform(cmd, c)
 	}
 	if err != nil {
 		return err
diff --git a/pkg/cmd/kamelet_add_repo.go b/pkg/cmd/kamelet_add_repo.go
index f7f8b6d9f..bb70f569b 100644
--- a/pkg/cmd/kamelet_add_repo.go
+++ b/pkg/cmd/kamelet_add_repo.go
@@ -80,9 +80,9 @@ func (o *kameletAddRepoCommandOptions) run(cmd *cobra.Command, args []string) er
 	}
 	var platform *v1.IntegrationPlatform
 	if o.OperatorID == "" {
-		platform, err = o.findIntegrationPlatorm(cmd, c)
+		platform, err = o.findIntegrationPlatform(cmd, c)
 	} else {
-		platform, err = o.getIntegrationPlatorm(cmd, c)
+		platform, err = o.getIntegrationPlatform(cmd, c)
 	}
 	if err != nil {
 		return err
@@ -100,8 +100,8 @@ func (o *kameletAddRepoCommandOptions) run(cmd *cobra.Command, args []string) er
 	return c.Update(o.Context, platform)
 }
 
-// getIntegrationPlatorm gives the integration plaform matching with the operator id in the provided namespace.
-func (o *kameletUpdateRepoCommandOptions) getIntegrationPlatorm(cmd *cobra.Command, c client.Client) (*v1.IntegrationPlatform, error) {
+// getIntegrationPlatform gives the integration platform matching with the operator id in the provided namespace.
+func (o *kameletUpdateRepoCommandOptions) getIntegrationPlatform(cmd *cobra.Command, c client.Client) (*v1.IntegrationPlatform, error) {
 	key := client.ObjectKey{
 		Namespace: o.Namespace,
 		Name:      o.OperatorID,
@@ -118,8 +118,8 @@ func (o *kameletUpdateRepoCommandOptions) getIntegrationPlatorm(cmd *cobra.Comma
 	return &platform, nil
 }
 
-// findIntegrationPlatorm gives the primary integration plaform that could be found in the provided namespace.
-func (o *kameletUpdateRepoCommandOptions) findIntegrationPlatorm(cmd *cobra.Command, c client.Client) (*v1.IntegrationPlatform, error) {
+// findIntegrationPlatform gives the primary integration platform that could be found in the provided namespace.
+func (o *kameletUpdateRepoCommandOptions) findIntegrationPlatform(cmd *cobra.Command, c client.Client) (*v1.IntegrationPlatform, error) {
 	platforms, err := platformutil.ListPrimaryPlatforms(o.Context, c, o.Namespace)
 	if err != nil {
 		return nil, err